from .Node import Node, DummyNode
from .Taxonomy import Taxonomy, load
from .Lineage import Lineage
from .utils import linne
from .__version__ import __version__, __title__, __description__
from .__version__ import __author__, __author_email__, __licence__
from .__version__ import __url__